%global libyui_major 16
Name:		dnfdragora
Version:	2.1.6
Release:	%mkrel 1
Summary:	DNF package-manager based on libYui abstraction
Group:		System/Packaging
License:	GPLv3+
URL:		https://github.com/manatools/%{name}
Source0:	%{url}/archive/%{version}/%{name}-%{version}.tar.gz

BuildArch:	noarch

BuildRequires:	cmake			>= 3.4.0
BuildRequires:	desktop-file-utils
BuildRequires:	gettext
BuildRequires:	appstream-util
BuildRequires:	pkgconfig
BuildRequires:	python3-devel		>= 3.4.0
BuildRequires:	python3-dnfdaemon
BuildRequires:  python3-sphinx
BuildRequires:	python3-yaml
BuildRequires:	python3-yui
BuildRequires:	python3-pyxdg
BuildRequires:	python3-cairosvg
BuildRequires:	python3-pillow
BuildRequires:	python3-pystray

Requires:	dnf			>= 2.2.0
Requires:	filesystem
Requires:	hicolor-icon-theme
Requires:	python3-dnfdaemon	>= 0.3.17
Requires:	python3-yaml
Requires:	python3-yui
Requires:	python3-manatools
# Ensure base TUI deps are installed
Requires:	libyui-ncurses%{libyui_major}
Requires:	libyui-mga-ncurses%{libyui_major}
# Suggest users to select a GUI
Recommends:	%{name}-gui = %{version}-%{release}

%description
%{name} is a DNF frontend, based on rpmdragora from Mageia
(originally rpmdrake) Perl code.

%{name} is written in Python 3 and uses libYui, the widget
abstraction library written by SUSE, so that it can be run
using Qt 5, GTK+ 3, or ncurses interfaces.

%package qt
Summary:	Qt frontend for %{name}
Group:		System/Packaging
Provides:	%{name}-gui = %{version}-%{release}
Requires:	%{name}-common = %{version}-%{release}
Requires:	libyui-qt%{libyui_major}
Requires:	libyui-mga-qt%{libyui_major}
Supplements:	(%{name} and qtbase5-common)

%description qt
This package pulls in the dependencies to run %{name} with a Qt5 GUI.

%package gtk
Summary:	GTK+ frontend for %{name}
Group:		System/Packaging
Provides:	%{name}-gui = %{version}-%{release}
Requires:	%{name}-common = %{version}-%{release}
Requires:	libyui-gtk%{libyui_major}
Requires:	libyui-mga-gtk%{libyui_major}
Supplements:	(%{name} and gtk+3)

%description gtk
This package pulls in the dependencies to run %{name} with a GTK+3 GUI.

%package common
Summary:	Shared files for Qt and GTK+ flavours of %{name}
Group:		System/Packaging
# It's silly to install this without the actual program...
Requires:	%{name} = %{version}-%{release}
# Without this requirement, it's possible to have desktop files installed
# that won't do anything, since there's no GUI deps installed.
Requires:	%{name}-gui = %{version}-%{release}

%description common
This package contains shared files used by the Qt and GTK+ flavours of
%{name}, which are not strictly necessary for the ncurses flavour of the
main %{name} package.


%package updater
Summary:	Update notifier applet for %{name}
Group:		System/Packaging
Requires:	%{name}-gui = %{version}-%{release}
Requires:	libnotify
Requires:	python3-pyxdg
Requires:	python3-cairosvg
Requires:	python3-pillow
Requires:	python3-pystray

%description updater
%{name} is a DNF frontend, based on rpmdragora from Mageia
(originally rpmdrake) Perl code.

%{name} is written in Python 3 and uses libYui, the widget
abstraction library written by SUSE, so that it can be run
using Qt 5, GTK+ 3, or ncurses interfaces.

This package provides the update notifier applet for %{name}.


%prep
%autosetup -p1


%build
%cmake	-DCHECK_RUNTIME_DEPENDENCIES=ON				\
	-DENABLE_COMPS=OFF					\
	-Wno-dev
%cmake_build


%install
%cmake_install

%find_lang %{name}

%check
# Validate desktop-files.
%{_bindir}/desktop-file-validate				\
	%{buildroot}%{_datadir}/applications/*.desktop

# Validate AppData-files.
%{_bindir}/appstream-util validate-relax --nonet		\
	%{buildroot}%{_datadir}/appdata/*.appdata.xml


%files -f %{name}.lang
%doc README.md TODO.md %{name}.yaml.example
%license AUTHORS LICENSE
%{_bindir}/%{name}
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.yaml
%{python3_sitelib}/%{name}/
%exclude %{python3_sitelib}/%{name}/updater.py
%exclude %{python3_sitelib}/%{name}/__pycache__/updater.cpython*.py?
%{_datadir}/%{name}/
%exclude %{_datadir}/applications/*%{name}-updater.desktop
%{_mandir}/man5/%{name}.yaml.5*
%{_mandir}/man8/%{name}.8*

%files updater
%{_bindir}/%{name}-updater
%{_datadir}/applications/*%{name}-updater.desktop
%{_sysconfdir}/xdg/autostart/*%{name}*.desktop
%{python3_sitelib}/%{name}/updater.py
%{python3_sitelib}/%{name}/__pycache__/updater.cpython*.py?

%files qt
# No files

%files gtk
# No files

%files common
%{_datadir}/appdata/*%{name}.appdata.xml
%{_datadir}/applications/*%{name}*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*


%changelog
* Wed Jan 10 2024 papoteur <papoteur> 2.1.6-1.mga9
+ Revision: 2029471
- new version 2.1.6

* Thu Mar 02 2023 papoteur <papoteur> 2.1.4-4.mga9
+ Revision: 1946312
- fix other requires name

* Thu Mar 02 2023 papoteur <papoteur> 2.1.4-3.mga9
+ Revision: 1946299
+ rebuild (emptylog)

* Thu Mar 02 2023 papoteur <papoteur> 2.1.4-2.mga9
+ Revision: 1946288
- adapt requirements to the new naming schema of libyui

* Sun Jan 15 2023 anaselli <anaselli> 2.1.4-1.mga9
+ Revision: 1933440
- New bug fixing release 2.1.4

* Sun Oct 02 2022 anaselli <anaselli> 2.1.3-1.mga9
+ Revision: 1894081
- New version 2.1.3

* Tue Feb 22 2022 tv <tv> 2.1.2-2.mga9
+ Revision: 1782757
- Rebuild for python-3.10

* Sun Oct 24 2021 anaselli <anaselli> 2.1.2-1.mga9
+ Revision: 1752791
- new version 2.1.2

* Sun Oct 03 2021 wally <wally> 2.1.1-3.mga9
+ Revision: 1748948
- fix libyui requires

* Sat Apr 10 2021 ngompa <ngompa> 2.1.1-2.mga9
+ Revision: 1714600
- Rebuild for Python 3.9

* Wed Jan 06 2021 anaselli <anaselli> 2.1.1-1.mga8
+ Revision: 1669235
- 2.1.1 minor fixing and translation release

* Fri Oct 09 2020 anaselli <anaselli> 2.1.0-4.mga8
+ Revision: 1633040
- Fixing dnfdragora-updater icon

* Sun Sep 13 2020 anaselli <anaselli> 2.1.0-3.mga8
+ Revision: 1625891
- Managed \n into description see https://bugs.mageia.org/show_bug.cgi?id=27274
- Managed \n into description see https://bugs.mageia.org/show_bug.cgi?id=27274

* Sun Sep 13 2020 anaselli <anaselli> 2.1.0-2.mga8
+ Revision: 1625678
- python manatools dependency

* Sun Sep 06 2020 anaselli <anaselli> 2.1.0-1.mga8
+ Revision: 1622958
- Version 2.1.0

* Sat Jul 04 2020 anaselli <anaselli> 2.0.4-3.mga8
+ Revision: 1601936
- added libyui so version dependency

* Mon Jun 29 2020 anaselli <anaselli> 2.0.4-2.mga8
+ Revision: 1600532
- rebuilt

* Wed Jun 17 2020 anaselli <anaselli> 2.0.4-1.mga8
+ Revision: 1594734
- 2.0.4

* Sat Jun 06 2020 anaselli <anaselli> 2.0.3-1.mga8
+ Revision: 1590787
- moved to TODO.md
- new version 2.0.3

* Thu Apr 23 2020 anaselli <anaselli> 2.0.2-1.mga8
+ Revision: 1571511
- bug fixing release 2.0.2

* Mon Apr 13 2020 anaselli <anaselli> 2.0.1-1.mga8
+ Revision: 1567122
- bug fixing releae 2.0.1

* Mon Apr 06 2020 anaselli <anaselli> 2.0.0-2.mga8
+ Revision: 1565032
- missing metadata entry in user setting caused a crash during startup

* Sun Apr 05 2020 anaselli <anaselli> 2.0.0-1.mga8
+ Revision: 1564985
- new version 2.0.0

* Fri Mar 27 2020 anaselli <anaselli> 1.1.2-4.mga8
+ Revision: 1561235
- Update for new libyui

* Sun Feb 16 2020 umeabot <umeabot> 1.1.2-3.mga8
+ Revision: 1536669
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Mon Oct 21 2019 daviddavid <daviddavid> 1.1.2-2.mga8
+ Revision: 1454878
- rebuild for python3.8

* Fri Apr 26 2019 ngompa <ngompa> 1.1.2-1.mga7
+ Revision: 1395574
- Rebase to 1.1.2

* Fri Jan 11 2019 tmb <tmb> 1.0.1-6.mga7
+ Revision: 1355147
- rebuild for python 3.7
+ anaselli <anaselli>
- rebuilt against new libyui

* Thu Sep 20 2018 umeabot <umeabot> 1.0.1-4.mga7
+ Revision: 1278034
- Mageia 7 Mass Rebuild

* Sat Aug 05 2017 pterjan <pterjan> 1.0.1-3.mga7
+ Revision: 1135204
- Rebuild for python 3.6

* Sun Apr 23 2017 ngompa <ngompa> 1.0.1-2.mga6
+ Revision: 1097132
- Add Requires dnfdragora to -common subpackage

* Sat Apr 15 2017 ngompa <ngompa> 1.0.1-1.mga6
+ Revision: 1096561
- Update to 1.0.1

* Tue Apr 04 2017 ngompa <ngompa> 1.0.0-5.mga6
+ Revision: 1095881
- Backport fixes to handle new signals from DNF 2.2.0

* Mon Mar 27 2017 akien <akien> 1.0.0-4.mga6
+ Revision: 1094998
- Split GUI-specific files (desktop, appdata) to -common shared dependency
- Make dnfdragora recommend -gui instead of require it, allows installing only the ncurses flavour

* Sun Feb 19 2017 ngompa <ngompa> 1.0.0-3.mga6
+ Revision: 1086962
- Disable comps, we don't use it in Mageia

* Sun Feb 19 2017 ngompa <ngompa> 1.0.0-2.mga6
+ Revision: 1086958
- Remove accidental comment block in package description

* Sun Feb 19 2017 ngompa <ngompa> 1.0.0-1.mga6
+ Revision: 1086953
- Import dnfdragora package


* Sun Feb 19 2017 Neal Gompa <ngompa13@gmail.com> - 1.0.0
- Upgrade to 1.0.0
- Port to Mageia

* Sun Feb 19 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.114.git20170218.58bd424
- New snapshot

* Wed Feb 15 2017 Igor Gnatenko <ignatenko@redhat.com> - 0.0.0-0.113.git20170213.289d170
- Rebuild for brp-python-bytecompile

* Tue Feb 14 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.112.git20170213.289d170
- New snapshot

* Wed Feb 08 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.111.git20170207.783aede
- New snapshot

* Sun Feb 05 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.110.git20170205.d929620
- New snapshot

* Sat Feb 04 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.109.git20170204.2c34e52
- New snapshot
- Drop patch, upstreamed
- Run CMake with '-Wno-dev'-flag

* Sat Feb 04 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.108.git20170204.f2bb4da
- Swap date and commit-sha in release-tag

* Sat Feb 04 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.107.gitf2bb4da.20170204
- Add patch to build and install translations with CMake

* Sat Feb 04 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.106.gitf2bb4da.20170204
- New snapshot

* Sat Feb 04 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.105.git708a8a8.20170204
- Drop Requires: libyui-mga-ncurses, dnf should be smart enough
  to select the MGA-UI with the least deps during installation

* Sat Feb 04 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.104.git708a8a8.20170204
- New snapshot

* Sat Feb 04 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.103.gita3492da.20170204
- New snapshot

* Fri Feb 03 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.102.git4d872ab.20170202
- New snapshot

* Fri Feb 03 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.101.gitcc4e556.20170202
- Add Requires: libyui-mga-ncurses for functionality with low dependencies

* Thu Feb 02 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.100.gitcc4e556.20170202
- Initial import (rhbz#1418788)
- Bump to 0.100 to superseed builds from COPR

* Thu Feb 02 2017 Björn Esser <besser82@fedoraproject.org> - 0.0.0-0.1.gitcc4e556.20170202
- Initial rpm-release (rhbz#1418788)
